.. currentmodule:: disnake_compass

Component Manager Implementation
================================

.. automodule:: disnake_compass.impl.manager

Functions
---------

.. autofunction:: disnake_compass.impl.manager.get_manager

.. autofunction:: disnake_compass.impl.manager.check_manager

Classes
-------

.. attributetable:: disnake_compass.impl.manager.ComponentManager

.. autoclass:: disnake_compass.impl.manager.ComponentManager
    :members:
    :exclude-members: parse_message_interaction
